.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/eelcovv/pymarine.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/eelcovv/pymarine
    .. image:: https://readthedocs.org/projects/pymarine/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://pymarine.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/eelcovv/pymarine/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/eelcovv/pymarine
    .. image:: https://img.shields.io/pypi/v/pymarine.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/pymarine/
    .. image:: https://img.shields.io/conda/vn/conda-forge/pymarine.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/pymarine
    .. image:: https://pepy.tech/badge/pymarine/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/pymarine

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

========
pymarine
========


    A collection of functions and classes for marine sea state modelling

This packages supplies several wave field models which can be used for marine applications.


===========
Information
===========

This projects gives a collection of spectral functions. It comes with the following modules

* wave_spectra : A set of functions to create wave spectra and distribution functions
* wave_fields : Create and simulate 1D and 2D waves based on the *wave_spectra* module

.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.5. For details and usage
information on PyScaffold see https://pyscaffold.org/.
